AnimationDgmOnlyBuildType

Enum AnimationDgmOnlyBuildType 

pub enum AnimationDgmOnlyBuildType {
    One,
    LvlOne,
    LvlAtOnce,
}
This simple type specifies the build options available only for animating a diagram. These options specify the manner in which the objects within the chart should be grouped and animated.

Variants



One

Animate the diagram by elements. For a tree diagram the animation occurs by branch within the diagram tree.



LvlOne

Animate the diagram by the elements within a level, animating them one level element at a time.



LvlAtOnce

Animate the diagram one level at a time, animating the whole level as one object