pub enum ChartBuildStep {
Category,
PtInCategory,
Series,
PtInSeries,
AllPts,
GridLegend,
}Expand description
This simple type specifies an animation build step within a chart animation.
Variants
Category
Animate a chart category for this animation build step
PtInCategory
Animate a point in a chart category for this animation build step
Series
Animate a chart series for this animation build step
PtInSeries
Animate a point in a chart series for this animation build step
AllPts
Animate all points within the chart for this animation build step
GridLegend
Animate the chart grid and legend for this animation build step