pub enum FillModeProperties {
Tile(Box<TileInfoProperties>),
Stretch(Box<StretchInfoProperties>),
}Variants
Tile(Box<TileInfoProperties>)
This element specifies that a BLIP should be tiled to fill the available space. This element defines a “tile” rectangle within the bounding box. The image is encompassed within the tile rectangle, and the tile rectangle is tiled across the bounding box to fill the entire area.
Stretch(Box<StretchInfoProperties>)
This element specifies that a BLIP should be stretched to fill the target rectangle. The other option is a tile where a BLIP is tiled to fill the available area.
Implementations
Sourceimpl FillModeProperties
impl FillModeProperties
pub fn is_choice_member(name: &str) -> bool
pub fn from_xml_element(xml_node: &XmlNode) -> Result<Self, Box<dyn Error>>