PresetLineDashVal

Enum PresetLineDashVal 

pub enum PresetLineDashVal {
    Solid,
    Dot,
    Dash,
    LargeDash,
    DashDot,
    LargeDashDot,
    LargeDashDotDot,
    SystemDash,
    SystemDot,
    SystemDashDot,
    SystemDashDotDot,
}
This simple type represents preset line dash values. The description for each style shows an illustration of the line style. Each style also contains a precise binary representation of the repeating dash style. Each 1 corresponds to a line segment of the same length as the line width, and each 0 corresponds to a space of the same length as the line width.

Variants



Solid

1



Dot

1000



Dash

1111000



LargeDash

11111111000



DashDot

11110001000



LargeDashDot

111111110001000



LargeDashDotDot

1111111100010001000



SystemDash

1110



SystemDot

10



SystemDashDot

111010



SystemDashDotDot

11101010