TextAnchoringType

Enum TextAnchoringType 

pub enum TextAnchoringType {
    Top,
    Center,
    Bottom,
    Justified,
    Distributed,
}
This simple type specifies a list of available anchoring types for text.

Variants



Top

Anchor the text at the top of the bounding rectangle.



Center

Anchor the text at the middle of the bounding rectangle.



Bottom

Anchor the text at the bottom of the bounding rectangle.



Justified

Anchor the text so that it is justified vertically. When text is horizontal, this spaces out the actual lines of text and is almost always identical in behavior to ‘distrib’ (special case: if only 1 line, then anchored at top). When text is vertical, then it justifies the letters vertically. This is different than anchorDistributed, because in some cases such as very little text in a line, it does not justify.



Distributed

Anchor the text so that it is distributed vertically. When text is horizontal, this spaces out the actual lines of text and is almost always identical in behavior to anchorJustified (special case: if only 1 line, then anchored in middle). When text is vertical, then it distributes the letters vertically. This is different than anchorJustified, because it always forces distribution of the words, even if there are only one or two words in a line.