pub enum TextVertOverflowType {
Overflow,
Ellipsis,
Clip,
}Expand description
This simple type specifies the text vertical overflow.
Variants
Overflow
Overflow the text and pay no attention to top and bottom barriers.
Ellipsis
Pay attention to top and bottom barriers. Use an ellipsis to denote that there is text which is not visible.
Clip
Pay attention to top and bottom barriers. Provide no indication that there is text which is not visible.