pub struct Connection {
pub id: DrawingElementId,
pub shape_index: u32,
}Fields
id: DrawingElementIdSpecifies the id of the shape to make the final connection to.
shape_index: u32Specifies the index into the connection site table of the final connection shape. That is there are many connection sites on a shape and it shall be specified which connection site the corresponding connector shape should connect to.
Implementations
Sourceimpl Connection
impl Connection