pub struct OuterShadowEffect {
pub blur_radius: Option<PositiveCoordinate>,
pub distance: Option<PositiveCoordinate>,
pub direction: Option<PositiveFixedAngle>,
pub scale_x: Option<Percentage>,
pub scale_y: Option<Percentage>,
pub skew_x: Option<FixedAngle>,
pub skew_y: Option<FixedAngle>,
pub alignment: Option<RectAlignment>,
pub rotate_with_shape: Option<bool>,
pub color: Color,
}Expand description
This element specifies an Outer Shadow Effect.
Fields
blur_radius: Option<PositiveCoordinate>Specifies the blur radius of the shadow.
Defaults to 0
distance: Option<PositiveCoordinate>Specifies the how far to offset the shadow.
Defaults to 0
direction: Option<PositiveFixedAngle>Specifies the direction to offset the shadow.
Defaults to 0
scale_x: Option<Percentage>Specifies the horizontal scaling factor; negative scaling causes a flip.
Defaults to 100_000
scale_y: Option<Percentage>Specifies the vertical scaling factor; negative scaling causes a flip.
Defaults to 100_000
skew_x: Option<FixedAngle>Specifies the horizontal skew angle.
Defaults to 0
skew_y: Option<FixedAngle>Specifies the vertical skew angle.
Defaults to 0
alignment: Option<RectAlignment>Specifies shadow alignment; alignment happens first, effectively setting the origin for scale, skew, and offset.
Defaults to RectAlignment::Bottom
rotate_with_shape: Option<bool>Specifies whether the shadow rotates with the shape if the shape is rotated.
Defaults to true
color: ColorImplementations