TextBody

Struct TextBody 

pub struct TextBody {
    pub body_properties: Box<TextBodyProperties>,
    pub list_style: Option<Box<TextListStyle>>,
    pub paragraph_array: Vec<Box<TextParagraph>>,
}

Fields

body_properties: Box<TextBodyProperties>

Specifies the properties of this text body.

list_style: Option<Box<TextListStyle>>

Specifies the list style of this text body.

paragraph_array: Vec<Box<TextParagraph>>

This element specifies the presence of a paragraph of text within the containing text body. The paragraph is the highest level text separation mechanism within a text body. A paragraph can contain text paragraph properties associated with the paragraph. If no properties are listed then properties specified in the defPPr element are used.

Xml example

Consider the case where the user would like to describe a text body that contains two paragraphs. The requirement for these paragraphs is that one be right aligned and the other left aligned. The following DrawingML would specify a text body such as this.

<p:txBody>
  …
  <a:p>
    <a:pPr algn="r">
    </a:pPr>
    …
    <a:t>Some text</a:t>
    …
  </a:p>
  <a:p>
    <a:pPr algn="l">
    </a:pPr>
    …
    <a:t>Some text</a:t>
    …
  </a:p>
</p:txBody>

Implementations

Source

impl TextBody

pub fn from_xml_element(xml_node: &XmlNode) -> Result<Self, Box<dyn Error>>