TextField

Struct TextField 

pub struct TextField {
    pub id: Guid,
    pub field_type: Option<String>,
    pub char_properties: Option<Box<TextCharacterProperties>>,
    pub paragraph_properties: Option<Box<TextParagraph>>,
    pub text: Option<String>,
}

Fields

id: Guid

Specifies the unique to this document, host specified token that is used to identify the field. This token is generated when the text field is created and persists in the file as the same token until the text field is removed. Any application should check the document for conflicting tokens before assigning a new token to a text field.

field_type: Option<String>

Specifies the type of text that should be used to update this text field. This is used to inform the rendering application what text it should use to update this text field. There are no specific syntax restrictions placed on this attribute. The generating application can use it to represent any text that should be updated before rendering the presentation.

Reserved values:

ValueDescription
slidenumpresentation slide number
datetimedefault date time format for the rendering application
datetime1MM/DD/YYYY date time format
datetime2Day, Month DD, YYYY date time format
datetime3DD Month YYYY date time format
datetime4Month DD, YYYY date time format
datetime5DD-Mon-YY date time format
datetime6Month YY date time format
datetime7Mon-YY date time format
datetime8MM/DD/YYYY hh:mm AM/PM date time format
datetime9MM/DD/YYYY hh:mm:ss AM/PM date time format
datetime10hh:mm date time format
datetime11hh:mm:ss date time format
datetime12hh:mm AM/PM date time format
datetime13hh:mm:ss: AM/PM date time format
char_properties: Option<Box<TextCharacterProperties>>

This element contains all run level text properties for the text runs within a containing paragraph.

Xml example

<a:p>
  …
  <a:rPr u="sng"/>
  …
  <a:t>Some Text</a:t>
  …
</a:p>

The run of text described above is formatting with a single underline of text matching color.

paragraph_properties: Option<Box<TextParagraph>>

Specifies the paragraph properties for this text field

text: Option<String>

The text of this text field.

Implementations

Source

impl TextField

pub fn from_xml_element(xml_node: &XmlNode) -> Result<Self, Box<dyn Error>>