pub enum EffectProperties {
EffectList(Box<EffectList>),
EffectContainer(Box<EffectContainer>),
}Variants
EffectList(Box<EffectList>)
This element specifies a list of effects. Effects in an effectLst are applied in the default order by the rendering engine. The following diagrams illustrate the order in which effects are applied, both for shapes and for group shapes.
Note
The output of many effects does not include the input shape. For effects that should be applied to the result of previous effects as well as the original shape, a container is used to group the inputs together.
Example
Outer Shadow is applied both to the original shape and the original shape’s glow. The result of blur contains the original shape, while the result of glow contains only the added glow. Therefore, a container that groups the blur result with the glow result is used as the input to Outer Shadow.
EffectContainer(Box<EffectContainer>)
This element specifies a list of effects. Effects are applied in the order specified by the container type (sibling or tree).
Note
An effectDag element can contain multiple effect containers as child elements. Effect containers with different styles can be combined in an effectDag to define a directed acyclic graph (DAG) that specifies the order in which all effects are applied.
Implementations