pub struct PositiveSize2D {
pub width: PositiveCoordinate,
pub height: PositiveCoordinate,
}Fields
width: PositiveCoordinateSpecifies the length of the extents rectangle in EMUs. This rectangle shall dictate the size of the object as displayed (the result of any scaling to the original object).
height: PositiveCoordinateSpecifies the width of the extents rectangle in EMUs. This rectangle shall dictate the size of the object as displayed (the result of any scaling to the original object).
Implementations