pub type Lang = String;Expand description
This simple type specifies that its contents contains a language identifier as defined by RFC 4646/BCP 47.
The contents of this language are interpreted based on the context of the parent XML element.
Xml example
<w:lang w:val="en-CA" />This language is therefore specified as English (en) and Canada (CA), resulting in use of the English (Canada) language setting.
Aliased Type
pub struct Lang { /* private fields */ }